@@ -1,5 +1,3 @@
-(* $Id: cppo_types.ml 72 2011-07-30 10:49:40Z mjambon $ *)
-
 open Printf
 open Lexing
 
@@ -18,14 +16,17 @@ type bool_expr =
     | `Eq of (arith_expr * arith_expr) (* = *)
     | `Lt of (arith_expr * arith_expr) (* < *)
     | `Gt of (arith_expr * arith_expr) (* > *)
-	(* syntax for additional operators: <>, <=, >= *)
+        (* syntax for additional operators: <>, <=, >= *)
     ]
 
 and arith_expr = (* signed int64 *)
     [ `Int of int64
     | `Ident of (loc * string)
-	(* must be bound to a valid int literal.
-	   Expansion of macro functions is not supported. *)
+        (* must be bound to a valid int literal.
+           Expansion of macro functions is not supported. *)
+
+    | `Tuple of (loc * arith_expr list)
+        (* tuple of 2 or more elements guaranteed by the syntax *)
 
     | `Neg of arith_expr (* - *)
     | `Add of (arith_expr * arith_expr) (* + *)
@@ -76,12 +77,12 @@ let string_of_loc (pos1, pos2) =
 exception Cppo_error of string
 
 let error loc s =
-  let msg = 
+  let msg =
     sprintf "%s\nError: %s" (string_of_loc loc) s in
   raise (Cppo_error msg)
 
 let warning loc s =
-  let msg = 
+  let msg =
     sprintf "%s\nWarning: %s" (string_of_loc loc) s in
   eprintf "%s\n%!" msg
 
